@@ -6,11 +6,12 @@ import dask.distributed as distributed
 
 def DNewton(func,grad,hess,bounds,x0,max_iter,tol,*args):
     e = np.inf
+    gradient = np.ones((len(x0))) * np.inf
     counter = 0
     x = np.array(x0)
     success = True
     grad_list = []
-    while e > tol:
+    while e > tol and np.linalg.norm(gradient) > tol:
         gradient = grad(x,*args)
         hessian  = hess(x,*args)
         grad_list.append(np.max(gradient))
@@ -20,7 +21,7 @@ def DNewton(func,grad,hess,bounds,x0,max_iter,tol,*args):
             gamma,a,b,c = np.linalg.lstsq(hessian,-gradient)
         x += gamma
         e = np.max(abs(gamma))
-        #print("e = ", e," gradient = ",gradient,flush = True)
+        #print("gamma = ", gamma," gradient = ",gradient,flush = True)
         if misc.out_of_bounds(x,bounds):
             x = np.random.uniform(low = bounds[:,0], high = bounds[:,1], size = len(bounds))
         if counter > max_iter:
